.. include:: ../README.rst

.. autosummary::
   :toctree: api
   :recursive:

   vecrec.Shape
   vecrec.Vector
   vecrec.Rect
   vecrec.cast_anything_to_vector
   vecrec.cast_anything_to_rectangle
   vecrec.cast_shape_to_rectangle
   vecrec.accept_anything_as_vector
   vecrec.accept_anything_as_rectangle
   vecrec.accept_shape_as_rectangle
   vecrec.golden_ratio
   vecrec.get_distance
   vecrec.interpolate
   vecrec.NullVectorError
   vecrec.VectorCastError
   vecrec.RectCastError
